@@ -1,17 +1,10 @@
-# Time-stamp: <2016-02-12 00:43:42 Tao Liu>
+# Time-stamp: <2019-09-20 11:30:27 taoliu>
 
 """Description: Modify bedGraph file
 
-Copyright (c) 2014 Tao Liu <tliu4@buffalo.edu>
-
 This code is free software; you can redistribute it and/or modify it
-under the terms of the BSD License (see the file COPYING included with
+under the terms of the BSD License (see the file LICENSE included with
 the distribution).
-
-@status:  experimental
-@version: $Revision$
-@author:  Tao Liu
-@contact: tliu4@buffalo.edu
 """
 
 # ------------------------------------
