@@ -1,3 +1,10 @@
+/* Time-stamp: <2019-09-20 11:33:22 taoliu>
+
+ This code is free software; you can redistribute it and/or modify it
+ under the terms of the BSD License (see the file LICENSE included
+ with the distribution).
+*/
+
 float log10_poisson_cdf ( unsigned int n, float lam, short lower );
 float log10_poisson_cdf_P_large_lambda ( unsigned int k, float lbd );
 float log10_poisson_cdf_Q_large_lambda ( unsigned int k, float lbd );
