@@ -1,18 +1,10 @@
-# Time-stamp: <2018-10-15 12:34:16 Tao Liu>
+# Time-stamp: <2019-09-25 10:03:54 taoliu>
 
 """Description: MACS 2 main executable
 
-Copyright (c) 2008,2009 Yong Zhang, Tao Liu <taoliu@jimmy.harvard.edu>
-Copyright (c) 2010,2011 Tao Liu <taoliu@jimmy.harvard.edu>
-
 This code is free software; you can redistribute it and/or modify it
-under the terms of the BSD License (see the file COPYING included
-with the distribution).
-
-@status: release candidate
-@version: $Id$
-@author:  Yong Zhang, Tao Liu
-@contact: taoliu@jimmy.harvard.edu
+under the terms of the BSD License (see the file LICENSE included with
+the distribution).
 """
 
 # ------------------------------------
@@ -29,10 +21,10 @@ import tempfile
 # own python modules
 # ------------------------------------
 from MACS2.OptValidator import opt_validate
-from MACS2.OutputWriter import *
 from MACS2.Prob import binomial_cdf_inv
 from MACS2.PeakModel import PeakModel,NotEnoughPairsException
 from MACS2.PeakDetect import PeakDetect
+from MACS2.OutputWriter import model2r_script
 from MACS2.Constants import *
 # ------------------------------------
 # Main function
@@ -302,7 +294,7 @@ def run( args ):
     if options.nolambda:
         ofhd_xls.write("# local lambda is disabled!\n")
     # pass write method so we can print too, and include name
-    peakdetect.peaks.write_to_xls(ofhd_xls, name = options.name)
+    peakdetect.peaks.write_to_xls(ofhd_xls, name = options.name.encode())
     ofhd_xls.close()
     #4.2 peaks in BED
     if options.log_pvalue != None:
@@ -317,24 +309,24 @@ def run( args ):
         #ofhd_bed.close()
         info("#4 Write peak in narrowPeak format file... %s" % (options.peakNarrowPeak))
         ofhd_bed = open( options.peakNarrowPeak, "w" )
-        peakdetect.peaks.write_to_narrowPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, score_column=score_column, trackline=options.trackline )
+        peakdetect.peaks.write_to_narrowPeak (ofhd_bed, name_prefix=b"%s_peak_", name=options.name.encode(), score_column=score_column, trackline=options.trackline )
         ofhd_bed.close()
         #4.2-2 summits in BED
         info("#4 Write summits bed file... %s" % (options.summitbed))
         ofhd_summits = open( options.summitbed, "w" )
-        peakdetect.peaks.write_to_summit_bed (ofhd_summits, name_prefix="%s_peak_", name=options.name,
-                                              description="Summits for %s (Made with MACS v2, " + strftime("%x") + ")",
+        peakdetect.peaks.write_to_summit_bed (ofhd_summits, name_prefix="%s_peak_".encode(), name=options.name.encode(),
+                                              description=("Summits for %s (Made with MACS v2, " + strftime("%x") + ")").encode(),
                                               score_column=score_column, trackline=options.trackline )
         ofhd_summits.close()
     #4.2 broad peaks in bed12 or gappedPeak
     else:
         info("#4 Write broad peak in broadPeak format file... %s" % (options.peakBroadPeak))
         ofhd_bed = open( options.peakBroadPeak, "w" )
-        peakdetect.peaks.write_to_broadPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, description=options.name, trackline=options.trackline)
+        peakdetect.peaks.write_to_broadPeak (ofhd_bed, name_prefix=b"%s_peak_", name=options.name.encode(), description=options.name.encode(), trackline=options.trackline)
         ofhd_bed.close()
         info("#4 Write broad peak in bed12/gappedPeak format file... %s" % (options.peakGappedPeak))
         ofhd_bed = open( options.peakGappedPeak, "w" )
-        peakdetect.peaks.write_to_gappedPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, description=options.name, trackline=options.trackline)
+        peakdetect.peaks.write_to_gappedPeak (ofhd_bed, name_prefix=b"%s_peak_", name=options.name.encode(), description=options.name.encode(), trackline=options.trackline)
         ofhd_bed.close()
 
     info("Done!")
