@@ -1,17 +1,10 @@
-# Time-stamp: <2018-10-16 11:47:20 Tao Liu>
+# Time-stamp: <2019-09-25 10:30:22 taoliu>
 
 """Description: Filter duplicate reads depending on sequencing depth.
 
-Copyright (c) 2011 Tao Liu <taoliu@jimmy.harvard.edu>
-
 This code is free software; you can redistribute it and/or modify it
-under the terms of the BSD License (see the file COPYING included
-with the distribution).
-
-@status: release candidate
-@version: $Id$
-@author:  Yong Zhang, Tao Liu
-@contact: taoliu@jimmy.harvard.edu
+under the terms of the BSD License (see the file LICENSE included with
+the distribution).
 """
 
 # ------------------------------------
@@ -77,16 +70,11 @@ def run( o_options ):
             max_dup_tags = int(options.keepduplicates)
             info("filter out redundant tags at the same location and the same strand by allowing at most %d tag(s)" % (max_dup_tags))
 
-        if not options.dryrun:
-            inputtrack.filter_dup(max_dup_tags)
-            t1 = inputtrack.total
-        else:
-            t1 = inputtrack.filter_dup_dryrun( max_dup_tags )
+        t1 = inputtrack.filter_dup( max_dup_tags )
 
         info(" tags after filtering in alignment file: %d" % (t1))
         info(" Redundant rate of alignment file: %.2f" % (float(t0-t1)/t0))
             
-            
     if not options.dryrun:
         info( "Write to BED file" )
         inputtrack.print_to_bed( fhd=outfhd )
@@ -108,7 +96,7 @@ def load_tag_files_options ( options ):
 
     """
     options.info("# read treatment tags...")
-    tp = options.parser(options.ifile[0])
+    tp = options.parser(options.ifile[0], buffer_size=options.buffer_size)
     if not options.tsize:           # override tsize if user specified --tsize
         ttsize = tp.tsize()
         options.tsize = ttsize
@@ -117,7 +105,7 @@ def load_tag_files_options ( options ):
     if len(options.ifile) > 1:
         # multiple input
         for tfile in options.ifile[1:]:
-            tp = options.parser(tfile)
+            tp = options.parser(tfile, buffer_size=options.buffer_size)
             treat = tp.append_fwtrack( treat )
             #treat.sort()
     treat.finalize()
@@ -129,12 +117,12 @@ def load_frag_files_options ( options ):
     """
     options.info("# read treatment fragments...")
 
-    tp = options.parser(options.ifile[0])
+    tp = options.parser(options.ifile[0], buffer_size=options.buffer_size)
     treat = tp.build_petrack()
     if len(options.ifile) > 1:
         # multiple input
         for tfile in options.ifile[1:]:
-            tp = options.parser(ifile)
+            tp = options.parser(ifile, buffer_size=options.buffer_size)
             treat = tp.append_petrack( treat )
     treat.finalize()
     return treat
